@@ -1,6 +1,6 @@
 package App::RecordStream::Operation::fromdb;
 
-our $VERSION = "3.7";
+our $VERSION = "3.4";
 
 use strict;
 use warnings;
@@ -10,39 +10,37 @@ use base qw(App::RecordStream::Operation);
 use DBI;
 
 use App::RecordStream::DBHandle;
+use App::RecordStream::OutputStream;
 use App::RecordStream::Record;
 
 sub init {
-  my $this = shift;
-  my $args = shift;
+   my $this = shift;
+   my $args = shift;
 
-  my ($table_name, $sql);
-  my $spec = {
-    'table=s' => \$table_name,
-    'sql=s'   => \$sql,
-  };
+   my ($table_name, $sql);
+   my $spec = {
+      'table=s' => \$table_name,
+      'sql=s'   => \$sql,
+   };
 
-  $this->parse_options($args, $spec, ['pass_through']);
+   Getopt::Long::Configure("pass_through");
+   $this->parse_options($args, $spec);
 
-  $this->{'TABLE_NAME'} = $table_name;
+   $this->{'TABLE_NAME'} = $table_name;
 
-  my $dbh = App::RecordStream::DBHandle::get_dbh($args);
-  $this->{'DBH'} = $dbh;
+   my $dbh = App::RecordStream::DBHandle::get_dbh($this->_get_extra_args());
+   $this->{'DBH'} = $dbh;
 
-  die("Must define --table or --sql\n") unless ( $table_name || $sql );
+   die("Must define --table or --sql") unless ( $table_name || $sql );
 
-  unless ( $sql ) {
-    $sql = "SELECT * FROM $table_name";
-  }
+   unless ( $sql ) {
+     $sql = "SELECT * FROM $table_name";
+   }
 
-  $this->{'SQL'} = $sql;
+   $this->{'SQL'} = $sql;
 }
 
-sub wants_input {
-  return 0;
-}
-
-sub stream_done {
+sub run_operation {
   my $this = shift;
 
   my $sth = $this->{'DBH'}->prepare($this->{'SQL'});
@@ -55,27 +53,18 @@ sub stream_done {
 }
 
 sub usage {
-  my $this = shift;
-
-  my $options = [
-    [ 'table', 'Name of the table to dump, this is a shortcut for --sql \'SELECT * from tableName\''],
-    [ 'sql', 'SQL select statement to run'],
-  ];
-
-  my $args_string = $this->options_string($options);
-
-  my $usage =  <<USAGE;
-   __FORMAT_TEXT__
+   my $usage =  <<USAGE;
    Recs from DB will execute a select statement on a database of your choice,
    and create a record stream from the results.  The keys of the record will be
    the column names and the values the row values.
-   __FORMAT_TEXT__
 
-$args_string
+   --table - Name of the table to dump, this is a shortcut for
+             --sql 'SELECT * from tableName'
+   --sql   - SQL select statement to run
 
 USAGE
 
-  return $usage . App::RecordStream::DBHandle::usage() .  <<EXAMPLES;
+   return $usage . App::RecordStream::DBHandle::usage() .  <<EXAMPLES;
 Examples:
    # Dump a table
    recs-fromdb --type sqlite --dbfile testDb --table recs
